@@ -98,24 +98,24 @@ class ModelEndpointTests(BaseTest):
 
     def test_list_returns_all_items(self):
         results = self.list_endpoint.list(MockRequest())
-        self.assertEqual(len(results), Widget.objects.count())
+        self.assertEqual(len(results.data), Widget.objects.count())
 
     def test_list_obeys_endpoint_pagination_amount(self):
         self.list_endpoint.max_per_page = 1
         results = self.list_endpoint.list(MockRequest())
-        self.assertEqual(len(results), 1)
+        self.assertEqual(len(results.data), 1)
 
     def test_list__ajaxerror_if_can_list_isnt_set(self):
         self.assertRaises(AJAXError, self.category_endpoint.list, MockRequest())
 
     def test_out_of_range_returns_empty_list(self):
         results = self.list_endpoint.list(MockRequest(current_page=99))
-        self.assertEqual(len(results), 0)
+        self.assertEqual(len(results.data), 0)
 
     def test_request_doesnt_override_max_per_page(self):
         self.list_endpoint.max_per_page = 1
         results = self.list_endpoint.list(MockRequest(items_per_page=2))
-        self.assertEqual(len(results), 1)
+        self.assertEqual(len(results.data), 1)
 
     def test_list_has_permission__default_empty(self):
         Category.objects.create(title='test')
@@ -123,4 +123,29 @@ class ModelEndpointTests(BaseTest):
         self.category_endpoint.can_list = lambda *args, **kwargs: True
 
         results = self.category_endpoint.list(MockRequest())
-        self.assertEqual(0, len(results))
+        self.assertEqual(0, len(results.data))
+
+    def test_list_has_total(self):
+        self.category_endpoint.can_list = lambda *args, **kwargs: True
+
+        results = self.list_endpoint.list(MockRequest())
+        self.assertEqual(6, results.metadata['total'])
+
+class ModelEndpointPostTests(TestCase):
+    """
+    Integration test for full urls->views->endpoint->encoder (and back) cycle.
+    """
+    def setUp(self):
+        for title in ['first', 'second', 'third']:
+            Widget.objects.create(title=title)
+        u = User(email='test@example.org', username='test')
+        u.set_password('password')
+        u.save()
+
+    def test_can_request_list_with_total(self):
+        self.client.login(username='test', password='password')
+
+        resp = self.client.post('/ajax/example/widget/list.json')
+        content = json.loads(resp.content)
+        self.assertTrue('total' in content.keys())
+        self.assertEquals(content['total'], 3)
\ No newline at end of file
